@@ -7,49 +7,53 @@ from tqdm import tqdm
 from numba import jit
 
 
-
-def period(series) -> None:
+def observation(series) -> None:
     """
     Calculate the period of observation.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
     """
     last = np.max(series.time)
     first = np.min(series.time)
-    series.period = last - first
-
+    series.observation = last - first
 
 
 def sampling(series) -> None:
     """
     Calculate the sampling rate.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
     """
-    period(series)
-    series.freq = (1 / series.period)
+    observation(series)
+    series.sampling = (1 / series.observation)
 
 
 @jit(nopython=True, parallel=True)
 def phase(times: np.array, bins: float) -> np.array:
     """
     Calculate the phase values.
+
     Parameters
     ----------
     times : np.array
         An array that represents the times.
     bins : float
         A float that represents the frequency.
+
     Returns
     -------
     values : np.array
@@ -65,10 +69,12 @@ def phase(times: np.array, bins: float) -> np.array:
 def sine(phases: np.array) -> np.array:
     """
     Calculate the sine values.
+
     Parameters
     ----------
     phases : np.array
         An array that represents the phase values.
+
     Returns
     -------
     values : np.array
@@ -82,10 +88,12 @@ def sine(phases: np.array) -> np.array:
 def cosine(phases: np.array) -> np.array:
     """
     Calculate the cosine values.
+
     Parameters
     ----------
     phases : np.array
         An array that represents the phase values.
+
     Returns
     -------
     values : np.array
@@ -99,10 +107,12 @@ def cosine(phases: np.array) -> np.array:
 def summation(phases: np.array) -> float:
     """
     Calculate the summation value.
+
     Parameters
     ----------
     phases : np.array
         An array that represents the phase values.
+
     Returns
     -------
     value : float
@@ -116,10 +126,12 @@ def summation(phases: np.array) -> float:
 def square(value: float) -> float:
     """
     Calculate the square values.
+
     Parameters
     ----------
     value : float
         A float that represents the summation value.
+
     Returns
     -------
     squared : float
@@ -133,12 +145,14 @@ def square(value: float) -> float:
 def z2n(sin: float, cos: float) -> float:
     """
     Calculate the z2n potency value.
+
     Parameters
     ----------
     sin : float
         A float that represents the sine value.
     cos : float
         A float that represents the cosine value.
+
     Returns
     -------
     value : float
@@ -152,12 +166,14 @@ def z2n(sin: float, cos: float) -> float:
 def normalization(z2n: np.array, norm: float) -> np.array:
     """
     Calculate the normalization values.
+
     Parameters
     ----------
     z2n : np.array
         An array that represents the z2n values.
     norm : float
         A float that represents the normalization.
+
     Returns
     -------
     values : np.array
@@ -170,10 +186,12 @@ def normalization(z2n: np.array, norm: float) -> np.array:
 def periodogram(series) -> None:
     """
     Calculate the Z2n statistics.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
@@ -188,62 +206,83 @@ def periodogram(series) -> None:
     series.z2n = normalization(series.z2n, (2 / series.time.size))
 
 
-
 def potency(series) -> None:
     """
     Calculate the natural potency.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
     """
-    series.pot = np.max(series.z2n)
-
+    series.potency = np.max(series.z2n)
 
 
 def frequency(series) -> None:
     """
     Calculate the natural frequency.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
     """
     index = np.argmax(series.z2n)
-    series.peak = series.bins[index]
+    series.frequency = series.bins[index]
 
 
-
-def pfraction(series) -> None:
+def period(series) -> None:
     """
-    Calculate the pulsed fraction.
+    Calculate the peak period.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
     """
     frequency(series)
-    pfrac = (2 * series.peak) / series.time.size
-    series.pulsed = pfrac ** 0.5
+    series.period = 1 / series.frequency
 
 
+def pfraction(series) -> None:
+    """
+    Calculate the pulsed fraction.
+
+    Parameters
+    ----------
+    series : Series
+        A time series object.
+
+    Returns
+    -------
+    None
+    """
+    frequency(series)
+    pfrac = (2 * series.potency) / series.time.size
+    series.pulsed = pfrac ** 0.5
+
 
 def forest(series) -> None:
     """
     Calculate the forest potency.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
@@ -255,26 +294,26 @@ def forest(series) -> None:
     series.forest = np.mean([series.z2n[low], series.z2n[up]])
 
 
-
 def bandwidth(series) -> None:
     """
     Calculate the bandwidth.
+
     Parameters
     ----------
     series : Series
         A time series object.
+
     Returns
     -------
     None
     """
     forest(series)
-    series.band = series.pot - series.forest
-
+    series.bandwidth = series.potency - series.forest
 
 
 def error(series) -> None:
     """
-    Calculate the uncertainty.
+    Calculate the uncertainty of the frequency.
     Parameters
     ----------
     series : Series
@@ -284,10 +323,10 @@ def error(series) -> None:
     None
     """
     bandwidth(series)
-    intersections = np.where(np.isclose(series.z2n, series.band, 0.1))
+    intersections = np.where(np.isclose(series.z2n, series.bandwidth, 0.1))
     if intersections[0].size:
-        low = series.peak - series.bins[intersections[0][0]]
-        up = series.bins[intersections[0][-1]] - series.peak
+        low = series.frequency - series.bins[intersections[0][0]]
+        up = series.bins[intersections[0][-1]] - series.frequency
         series.error = np.mean([low, up])
     else:
         series.error = 0
